@@ -1,5 +1,5 @@
 package Template::Liquid;
-our $VERSION = '1.0.10';
+our $VERSION = '1.0.11';
 our (%tags, %filters);
 #
 use Template::Liquid::Document;
@@ -8,7 +8,7 @@ use Template::Liquid::Tag;
 use Template::Liquid::Block;
 use Template::Liquid::Condition;
 sub register_tag { $tags{$_} = scalar caller for @_ }
-sub tags {%tags}
+sub tags         {%tags}
 use Template::Liquid::Tag::Assign;
 use Template::Liquid::Tag::Break;
 use Template::Liquid::Tag::Capture;
@@ -21,24 +21,21 @@ use Template::Liquid::Tag::If;
 use Template::Liquid::Tag::Raw;
 use Template::Liquid::Tag::Unless;
 sub register_filter { $filters{$_} = scalar caller for @_ }
-sub filters {%filters}
+sub filters         {%filters}
 
 # merge
 use Template::Liquid::Filters;
 #
 sub new {
     my ($class) = @_;
-    my $s = bless {break    => 0,
-                   continue => 0,
-                   tags     => {},
-                   filters  => {}
-    }, $class;
+    my $s = bless {break => 0, continue => 0, tags => {}, filters => {}},
+        $class;
     return $s;
 }
 
 sub parse {
     my ($class, $source) = @_;
-    my $s = ref $class ? $class : $class->new();
+    my $s      = ref $class ? $class : $class->new();
     my @tokens = Template::Liquid::Utility::tokenize($source);
     $s->{'document'} ||= Template::Liquid::Document->new({template => $s});
     $s->{'document'}->parse(\@tokens);
@@ -47,7 +44,8 @@ sub parse {
 
 sub render {
     my ($s, %assigns) = @_;
-    $s->{context} = Template::Liquid::Context->new(template => $s, assigns => \%assigns);
+    $s->{context} = Template::Liquid::Context->new(template => $s,
+                                                   assigns => \%assigns);
     return $s->{document}->render();
 }
 1;
@@ -69,8 +67,7 @@ Template::Liquid - A Simple, Stateless Template System
 
 =head1 Description
 
-The original Liquid template engine was crafted for very specific
-requirements:
+The original Liquid template engine was crafted for very specific requirements:
 
 =over 4
 
@@ -190,8 +187,7 @@ For more, see L<Template::Liquid::Tag::Raw|Template::Liquid::Tag::Raw>.
     {% endunless %}
 
 For more, see L<Template::Liquid::Tag::If|Template::Liquid::Tag::If> and
-L<Template::Liquid::Condition|Template::Liquid::Condition>.
-.
+L<Template::Liquid::Condition|Template::Liquid::Condition>. .
 
 =head2 C<unless> / C<elseif> / C<else>
 
@@ -244,8 +240,8 @@ has built-in support for such operations, using the cycle tag.
 If no name is supplied for the cycle group, then it's assumed that multiple
 calls with the same parameters are one group.
 
-If you want to have total control over cycle groups, you can optionally
-specify the name of the group. This can even be a variable.
+If you want to have total control over cycle groups, you can optionally specify
+the name of the group. This can even be a variable.
 
     {% cycle 'group 1': 'one', 'two', 'three' %}
     {% cycle 'group 1': 'one', 'two', 'three' %}
@@ -273,9 +269,9 @@ Please see see L<Template::Liquid::Tag::For|Template::Liquid::Tag::For>.
 
 =head2 C<assign>
 
-You can store data in your own variables, to be used in output or other tags
-as desired. The simplest way to create a variable is with the assign tag,
-which has a pretty straightforward syntax:
+You can store data in your own variables, to be used in output or other tags as
+desired. The simplest way to create a variable is with the assign tag, which
+has a pretty straightforward syntax:
 
     {% assign name = 'freestyle' %}
 
@@ -304,8 +300,8 @@ For more, see L<Template::Liquid::Tag::Assign|Template::Liquid::Tag::Assign>.
 =head2 C<capture>
 
 This tag is a block which "captures" whatever is rendered inside it, then
-assigns the captured value to the given variable instead of rendering it to
-the screen.
+assigns the captured value to the given variable instead of rendering it to the
+screen.
 
     {% capture attribute_name %}{{ item.title | handleize }}-{{ i }}-color{% endcapture %}
 
@@ -320,8 +316,7 @@ For more, see L<Template::Liquid::Tag::Capture|Template::Liquid::Tag::Capture>.
 
 =head1 Standard Liquid Filters
 
-Please see
-L<Template::Liquid::Filters::Standard|Template::Liquid::Filters::Standard>.
+Please see L<Template::Liquid::Filters|Template::Liquid::Filters>.
 
 =head1 Extending Template::Liquid
 
@@ -330,15 +325,15 @@ simple. Keep reading.
 
 =head2 Custom Tags
 
-See the section entitled
-L<Extending Template::Liquid with Custom Tags|Template::Liquid::Tag/"Extending Template::Liquid with Custom Tags">
-in L<Template::Liquid::Tag> for more information.
+See the section entitled L<Extending Template::Liquid with Custom
+Tags|Template::Liquid::Tag/"Extending Template::Liquid with Custom Tags"> in
+L<Template::Liquid::Tag> for more information.
 
 Also check out the examples of L<Template::LiquidX::Tag::Dump> and
 L<Template::LiquidX::Tag::Include> now on CPAN.
 
-To assist with custom tag creation, Template::Liquid provides several basic tag types
-for subclassing and exposes the following methods:
+To assist with custom tag creation, Template::Liquid provides several basic tag
+types for subclassing and exposes the following methods:
 
 =head3 C<< Template::Liquid::register_tag( ... ) >>
 
@@ -352,8 +347,8 @@ both a C<parse> and C<render> method.
     Template::Liquid::register_tag( 'newtag' );
     # ...and Template::Liquid will assume the new tag is in the calling package
 
-Pre-existing tags are replaced when new tags are registered with the same
-name. You may want to do this to override some functionality.
+Pre-existing tags are replaced when new tags are registered with the same name.
+You may want to do this to override some functionality.
 
 =head2 Custom Filters
 
@@ -364,8 +359,8 @@ by design and must return the modified content.
 
 =head3 C<< Template::Liquid::register_filter( ... ) >>
 
-This registers a package which Template::Liquid will assume contains one or more
-filters.
+This registers a package which Template::Liquid will assume contains one or
+more filters.
 
     # Register a package as a filter
     Template::Liquid::register_filter( 'Template::Solution::Filter::Amalgamut' );
@@ -413,11 +408,11 @@ I'd really rather use Solution::{Package} for extentions but Template::LiquidX
 really is a better choice.
 
 As I understand it, the original project's name, Liquid, is a reference to the
-classical states of matter (the engine itself being stateless). I wanted to
-use L<solution|http://en.wikipedia.org/wiki/Solution> because it's liquid but
-with bits of other stuff floating in it. (Pretend you majored in chemistry
-instead of mathematics or computer science.) Liquid tempates will I<always>
-work with Template::Liquid but (due to Template::LiquidX's expanded syntax)
+classical states of matter (the engine itself being stateless). I wanted to use
+L<solution|http://en.wikipedia.org/wiki/Solution> because it's liquid but with
+bits of other stuff floating in it. (Pretend you majored in chemistry instead
+of mathematics or computer science.) Liquid tempates will I<always> work with
+Template::Liquid but (due to Template::LiquidX's expanded syntax)
 Template::LiquidX templates I<may not> be compatible with Liquid or
 Template::Liquid.
 
@@ -430,24 +425,23 @@ CPAN ID: SANKO
 =encoding utf8
 
 The original Liquid template system was developed by
-L<jadedPixel|http://jadedpixel.com/> and
-L<Tobias Lütke|http://blog.leetsoft.com/>.
+L<jadedPixel|http://jadedpixel.com/> and L<Tobias
+Lütke|http://blog.leetsoft.com/>.
 
 =head1 License and Legal
 
 Copyright (C) 2009-2016 by Sanko Robinson <sanko@cpan.org>
 
 This program is free software; you can redistribute it and/or modify it under
-the terms of
-L<The Artistic License 2.0|http://www.perlfoundation.org/artistic_license_2_0>.
-See the F<LICENSE> file included with this distribution or
-L<notes on the Artistic License 2.0|http://www.perlfoundation.org/artistic_2_0_notes>
-for clarification.
+the terms of L<The Artistic License
+2.0|http://www.perlfoundation.org/artistic_license_2_0>. See the F<LICENSE>
+file included with this distribution or L<notes on the Artistic License
+2.0|http://www.perlfoundation.org/artistic_2_0_notes> for clarification.
 
-When separated from the distribution, all original POD documentation is
-covered by the
-L<Creative Commons Attribution-Share Alike 3.0 License|http://creativecommons.org/licenses/by-sa/3.0/us/legalcode>.
-See the
-L<clarification of the CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/us/>.
+When separated from the distribution, all original POD documentation is covered
+by the L<Creative Commons Attribution-Share Alike 3.0
+License|http://creativecommons.org/licenses/by-sa/3.0/us/legalcode>. See the
+L<clarification of the
+CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/us/>.
 
 =cut
