@@ -1,5 +1,5 @@
 package Template::Liquid::Filters;
-our $VERSION = '1.0.10';
+our $VERSION = '1.0.11';
 
 sub import {
     Template::Liquid::register_filter(
@@ -19,7 +19,7 @@ sub date {
     $_[0] = time() if lc $_[0] eq 'now' || lc $_[0] eq 'today';
     $_[1] = defined $_[1] ? $_[1] : '%c';
     return $_[0]->strftime($_[1]) if ref $_[0] && $_[0]->can('strftime');
-    return if $_[0] !~ m[^(\d*\.)?\d+?$]o;
+    return                        if $_[0] !~ m[^(\d*\.)?\d+?$]o;
     require POSIX;
     return POSIX::strftime($_[1], gmtime($_[0]));
 }
@@ -44,7 +44,7 @@ sub split { [split $_[1], $_[0]] }
 
 sub sort {
     return [sort { $a <=> $b } @{$_[0]}] if ref $_[0] eq 'ARRAY';
-    return sort keys %{$_[0]} if ref $_[0] eq 'HASH';
+    return sort keys %{$_[0]}            if ref $_[0] eq 'HASH';
     return $_[0];
 }
 
@@ -85,8 +85,9 @@ sub truncate {
     return if !$data;
     my $l = $length - length($truncate_string);
     $l = 0 if $l < 0;
-    return length($data) > $length ?
-        substr($data, 0, $l) . $truncate_string
+    return
+        length($data) > $length
+        ? substr($data, 0, $l) . $truncate_string
         : $data;
 }
 
@@ -96,38 +97,36 @@ sub truncatewords {
     $truncate_string = defined $truncate_string ? $truncate_string : '...';
     return if !$data;
     my @wordlist = split ' ', $data;
-    my $l = $words - 1;
+    my $l        = $words - 1;
     $l = 0 if $l < 0;
     return $#wordlist > $l
-        ?
-        CORE::join(' ', @wordlist[0 .. $l]) . $truncate_string
+        ? CORE::join(' ', @wordlist[0 .. $l]) . $truncate_string
         : $data;
 }
-sub prepend { return (defined $_[1] ? $_[1] : '') . $_[0]; }
-sub append { return $_[0] . (defined $_[1] ? $_[1] : ''); }
+sub prepend { return (defined $_[1]         ? $_[1] : '') . $_[0]; }
+sub append  { return $_[0] . (defined $_[1] ? $_[1] : ''); }
 
 sub minus {
-    return $_[0] =~ m[^[\+-]?(\d*\.)?\d+?$]o
-        && $_[1] =~ m[^[\+-]?(\d*\.)?\d+?$]o ? $_[0] - $_[1] : ();
+    return $_[0] =~ m[^[\+-]?(\d*\.)?\d+?$]o &&
+        $_[1] =~ m[^[\+-]?(\d*\.)?\d+?$]o ? $_[0] - $_[1] : ();
 }
 
 sub plus {
-    return $_[0] =~ m[^[\+-]?(\d*\.)?\d+?$]o
-        && $_[1] =~ m[^[\+-]?(\d*\.)?\d+?$]o ? $_[0] + $_[1] : $_[0] . $_[1];
+    return $_[0] =~ m[^[\+-]?(\d*\.)?\d+?$]o &&
+        $_[1] =~ m[^[\+-]?(\d*\.)?\d+?$]o ? $_[0] + $_[1] : $_[0] . $_[1];
 }
 
 sub times {
-    return $_[0] if $_[1] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
+    return $_[0]         if $_[1] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
     return $_[0] x $_[1] if $_[0] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
     return $_[0] * $_[1];
 }
 sub divided_by { return $_[0] / $_[1]; }
 
 sub modulo {
-    return (
-         (!defined $_[0] && $_[0] =~ m[[\+-]?[^\d\.]]o) ? '' : (!defined $_[1]
-                        && $_[1] =~ m[[\+-]?[^\d\.]]o) ? $_[0] : $_[0] % $_[1]
-    );
+    return (  (!defined $_[0] && $_[0] =~ m[[\+-]?[^\d\.]]o) ? ''
+            : (!defined $_[1] && $_[1] =~ m[[\+-]?[^\d\.]]o) ? $_[0]
+            :                                                  $_[0] % $_[1]);
 }
 sub floor { int $_[0] }
 sub ceil  { int($_[0] + 1) }
@@ -135,25 +134,22 @@ sub abs   { CORE::abs($_[0]) }
 
 sub money {
     return if $_[0] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
-    return (  ($_[0] < 0     ? '-'   : '')
-            . (defined $_[1] ? $_[1] : '$')
-                . sprintf '%.2f',
+    return (($_[0] < 0 ? '-' : '') . (defined $_[1] ? $_[1] : '$') .
+                sprintf '%.2f',
             CORE::abs($_[0])
     );
 }
 
 sub stock_price {
     return if $_[0] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
-    return (  ($_[0] < 0     ? '-'   : '')
-            . (defined $_[1] ? $_[1] : '$')
-                . sprintf '%.'
-                . (int(CORE::abs($_[0])) > 0 ? 2 : 4) . 'f',
+    return (($_[0] < 0 ? '-' : '') . (defined $_[1] ? $_[1] : '$') .
+                sprintf '%.' . (int(CORE::abs($_[0])) > 0 ? 2 : 4) . 'f',
             CORE::abs($_[0])
     );
 }
 
 sub default {
-    return length $_[0] ? $_[0] : $_[1] if !ref $_[0];
+    return length $_[0]  ? $_[0] : $_[1] if !ref $_[0];
     return defined $_[0] ? $_[0] : $_[1];
 }
 #
@@ -249,8 +245,8 @@ Using last on a string returns the last character in the string.
 
 =head1 Standard Filters
 
-These are the current default filters. They have been written to behave
-exactly like their Ruby Liquid counterparts accept where Perl makes improvment
+These are the current default filters. They have been written to behave exactly
+like their Ruby Liquid counterparts accept where Perl makes improvment
 irresistable.
 
 =head2 C<date>
@@ -274,8 +270,8 @@ This is the last resort and flags may differ by system so... Buyer beware.
 
 =back
 
-The C<date> filter also supports simple replacements of C<'now'> and
-C<'today'> with the current time. For example:
+The C<date> filter also supports simple replacements of C<'now'> and C<'today'>
+with the current time. For example:
 
     {{ 'now' | date :'%Y' }}
 
@@ -315,8 +311,8 @@ Sort elements of the array.
 
 =head2 C<size>
 
-Return the size of an array, the length of a string, or the number of keys in
-a hash. Undefined values return C<0>.
+Return the size of an array, the length of a string, or the number of keys in a
+hash. Undefined values return C<0>.
 
     # Where array is [1..6] and hash is { child => 'blarg'}
     {{ array     | size }} => 6
@@ -326,9 +322,9 @@ a hash. Undefined values return C<0>.
 
 =head2 C<strip_html>
 
-Strip html from string. Note that this filter uses C<s[<.*?>][]g> in
-emmulation of the Ruby Liquid library's strip_html function. ...so don't email
-me if you (correcly) think this is a braindead way of stripping html.
+Strip html from string. Note that this filter uses C<s[<.*?>][]g> in emmulation
+of the Ruby Liquid library's strip_html function. ...so don't email me if you
+(correcly) think this is a braindead way of stripping html.
 
     {{ '<div>Hello, <em id="whom">world!</em></div>' | strip_html }}  => Hello, world!
     '{{ '<IMG SRC = "foo.gif" ALT = "A > B">'        | strip_html }}' => ' B">'
@@ -432,8 +428,7 @@ Simple addition or string contatenation.
 
 =head3 MATHFAIL!
 
-Please note that integer behavior differs with Perl vs. Ruby
-so...
+Please note that integer behavior differs with Perl vs. Ruby so...
 
     {{ '1' | plus:'1' }}
 
@@ -533,16 +528,15 @@ CPAN ID: SANKO
 Copyright (C) 2009-2016 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
-the terms of
-L<The Artistic License 2.0|http://www.perlfoundation.org/artistic_license_2_0>.
-See the F<LICENSE> file included with this distribution or
-L<notes on the Artistic License 2.0|http://www.perlfoundation.org/artistic_2_0_notes>
-for clarification.
+the terms of L<The Artistic License
+2.0|http://www.perlfoundation.org/artistic_license_2_0>. See the F<LICENSE>
+file included with this distribution or L<notes on the Artistic License
+2.0|http://www.perlfoundation.org/artistic_2_0_notes> for clarification.
 
-When separated from the distribution, all original POD documentation is
-covered by the
-L<Creative Commons Attribution-Share Alike 3.0 License|http://creativecommons.org/licenses/by-sa/3.0/us/legalcode>.
-See the
-L<clarification of the CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/us/>.
+When separated from the distribution, all original POD documentation is covered
+by the L<Creative Commons Attribution-Share Alike 3.0
+License|http://creativecommons.org/licenses/by-sa/3.0/us/legalcode>. See the
+L<clarification of the
+CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/us/>.
 
 =cut
