@@ -1,5 +1,5 @@
 package Template::Liquid::Tag::If;
-our $VERSION = '1.0.10';
+our $VERSION = '1.0.11';
 require Template::Liquid::Error;
 require Template::Liquid::Utility;
 use base 'Template::Liquid::Tag';
@@ -12,10 +12,8 @@ sub new {
                                    fatal   => 1
         }
         if !defined $args->{'template'};
-    raise Template::Liquid::Error {type    => 'Context',
-                                   message => 'Missing parent argument',
-                                   fatal   => 1
-        }
+    raise Template::Liquid::Error {type => 'Context',
+                             message => 'Missing parent argument', fatal => 1}
         if !defined $args->{'parent'};
     raise Template::Liquid::Error {
                    type    => 'Syntax',
@@ -56,8 +54,7 @@ sub push_block {
 sub render {
     my ($s) = @_;
     for my $block (@{$s->{'blocks'}}) {
-        return $block->render()
-            if grep { $_ || 0 } @{$block->{'conditions'}};
+        return $block->render() if grep { $_ || 0 } @{$block->{'conditions'}};
     }
 }
 1;
@@ -89,8 +86,8 @@ Liquid supports compound inequalities. Try these...
 
 =head1 Bugs
 
-Liquid's (and by extension L<Template::Liquid|Template::Liquid>'s) treatment
-of compound inequalities is broken. For example...
+Liquid's (and by extension L<Template::Liquid|Template::Liquid>'s) treatment of
+compound inequalities is broken. For example...
 
     {% if 'This and that' contains 'that' and 1 == 3 %}
 
@@ -127,9 +124,9 @@ the terms of The Artistic License 2.0.  See the F<LICENSE> file included with
 this distribution or http://www.perlfoundation.org/artistic_license_2_0.  For
 clarification, see http://www.perlfoundation.org/artistic_2_0_notes.
 
-When separated from the distribution, all original POD documentation is
-covered by the Creative Commons Attribution-Share Alike 3.0 License.  See
-http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
-clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
+When separated from the distribution, all original POD documentation is covered
+by the Creative Commons Attribution-Share Alike 3.0 License.  See
+http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For clarification,
+see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
 =cut
