@@ -1,5 +1,5 @@
 package Template::Liquid::Variable;
-our $VERSION = '1.0.10';
+our $VERSION = '1.0.11';
 require Template::Liquid::Error;
 use strict;
 use warnings;
@@ -11,12 +11,10 @@ sub new {
                                    message => 'Missing template argument',
                                    fatal   => 1
         }
-        if !defined $args->{'template'}
-        || !$args->{'template'}->isa('Template::Liquid');
-    raise Template::Liquid::Error {type    => 'Context',
-                                   message => 'Missing parent argument',
-                                   fatal   => 1
-        }
+        if !defined $args->{'template'} ||
+        !$args->{'template'}->isa('Template::Liquid');
+    raise Template::Liquid::Error {type => 'Context',
+                             message => 'Missing parent argument', fatal => 1}
         if !defined $args->{'parent'};
     raise Template::Liquid::Error {
                    type    => 'Syntax',
@@ -36,7 +34,7 @@ sub render {
         FILTER: for my $filter (@{$s->{filters}}) {
                 my ($name, $args) = @$filter;
                 my $package = $_filters{$name};
-                my $call = $package ? $package->can($name) : ();
+                my $call    = $package ? $package->can($name) : ();
                 if ($call) {
 
             #use Data::Dump qw[dump];
@@ -49,10 +47,8 @@ sub render {
             #warn sprintf 'After  %s(%s): %s', $name, dump($args), dump($val);
                     next FILTER;
                 }
-                raise Template::Liquid::Error {type    => 'UnknownFilter',
-                                               message => $name,
-                                               fatal   => 0
-                };
+                raise Template::Liquid::Error {type => 'UnknownFilter',
+                                               message => $name, fatal => 0};
             }
         }
     }
@@ -81,8 +77,8 @@ handling echo statements:
 Internally, a variable is the basic container for everything; lists, scalars,
 hashes, and even objects.
 
-L<Filters|Template::Liquid::Filters::Standard> are applied to variables during
-the render stage.
+L<Filters|Template::Liquid::Filters> are applied to variables during the render
+stage.
 
 =head1 Author
 
@@ -95,16 +91,15 @@ CPAN ID: SANKO
 Copyright (C) 2009-2012 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
-the terms of
-L<The Artistic License 2.0|http://www.perlfoundation.org/artistic_license_2_0>.
-See the F<LICENSE> file included with this distribution or
-L<notes on the Artistic License 2.0|http://www.perlfoundation.org/artistic_2_0_notes>
-for clarification.
+the terms of L<The Artistic License
+2.0|http://www.perlfoundation.org/artistic_license_2_0>. See the F<LICENSE>
+file included with this distribution or L<notes on the Artistic License
+2.0|http://www.perlfoundation.org/artistic_2_0_notes> for clarification.
 
-When separated from the distribution, all original POD documentation is
-covered by the
-L<Creative Commons Attribution-Share Alike 3.0 License|http://creativecommons.org/licenses/by-sa/3.0/us/legalcode>.
-See the
-L<clarification of the CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/us/>.
+When separated from the distribution, all original POD documentation is covered
+by the L<Creative Commons Attribution-Share Alike 3.0
+License|http://creativecommons.org/licenses/by-sa/3.0/us/legalcode>. See the
+L<clarification of the
+CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/us/>.
 
 =cut
